@@ -19,9 +19,9 @@ from global_chem_extensions.analysis_tools.node_pca_analysis.node_pca_analysis i
 
 # Software Adapters
 
-from global_chem_extensions.software_adapters.smarts_visualizer import SmartsVisualizer
 from global_chem_extensions.software_adapters.pdf_adapter.molpdf_parser import MolPDFAdapter
 from global_chem_extensions.software_adapters.networkx_adapter.networkx_adapter import NetworkxAdapter
+from global_chem_extensions.software_adapters.smarts_visualizer.smarts_visualizer import SmartsVisualizer
 from global_chem_extensions.software_adapters.dimorphite_dl_adapter.dimorphite_dl import DimorphiteAdapter
 
 # Language Adapters
@@ -493,5 +493,5 @@ class GlobalChemExtensions(object):
             smarts
         )
 
-        visualizer.get_image()
+        return visualizer.get_image()
 
